/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.progstau.parameter;

/**
 * Schnittstelle für den Zugriff auf die Parameter der Stauverlaufsprognose.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface ISvpParameterObserver {
	/**
	 * liefert die Zeit, die bei der Bestimmung der Verkehrsstärke vor
	 * Anschlussstellen im Stau für die lineare Dämpfung vom aktuellen Messwert
	 * zur Prognoseganglinie verwendet wird.
	 *
	 * @return die Zeit
	 */
	long getDaempfungszeit();

	/**
	 * liefert den Faktor für die Bestimmung der Engpasskapazität bei der
	 * Verwendung des Fundamentaldiagramms.
	 *
	 * @return den Faktor
	 */
	long getFaktorQ0();

	/**
	 * liefert den geforderten Prognosehorizont.
	 *
	 * @return das Intervall in Sekunden
	 */
	long getHorizont();

	/**
	 * liefert die Anzahl der Iterationsschritte pro Zyklus der
	 * Stauobjektbestimmung.
	 *
	 * @return die Anzahl
	 */
	long getIterationen();

	/**
	 * liefert die Länge, die ein Pkw auf der Straße im Stau belegt (in Metern).
	 *
	 * @return die Länge
	 */
	long getLaengePkw();

	/**
	 * liefert die Schrittweite für die Prognose in Millisekunden.
	 *
	 * @return die Schrittweite
	 */
	long getSchrittWeite();
}
