/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import java.util.Iterator;

import org.junit.Assert;

import de.bsvrz.iav.gllib.gllib.dav.GanglinieMQ;
import de.bsvrz.iav.gllib.gllib.dav.GlProgAnfrage;
import de.bsvrz.iav.gllib.gllib.modell.onlinedaten.OdPrognoseGanglinienAnfrage;
import de.bsvrz.iav.gllib.gllib.modell.onlinedaten.OdPrognoseGanglinienAntwort;
import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.DatensatzUpdateEvent;
import de.bsvrz.sys.funclib.bitctrl.modell.DatensatzUpdateListener;
import de.bsvrz.sys.funclib.bitctrl.modell.DatensendeException;
import de.bsvrz.sys.funclib.bitctrl.modell.ObjektFactory;
import de.bsvrz.sys.funclib.bitctrl.modell.ganglinien.objekte.ApplikationGanglinienPrognose;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Applikation;

/**
 * Stellvertreter für die Ganglinienprognose. Die Klasse dient zur Berei
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class GanglinienPrognoseProxy implements DatensatzUpdateListener {

	/** das Netz, das die für den Test verwendeten Elemente verwaltet. */
	private final TestNetz netz;

	/**
	 * Konstruktor.
	 *
	 * @param netz
	 *            das verwendete Netz
	 */
	public GanglinienPrognoseProxy(final TestNetz netz) {

		this.netz = netz;

		final ApplikationGanglinienPrognose glProg = (ApplikationGanglinienPrognose) ObjektFactory.getInstanz()
				.getModellobjekt(ObjektFactory.getInstanz().getVerbindung().getLocalConfigurationAuthority());

		glProg.getOnlineDatensatz(OdPrognoseGanglinienAnfrage.class)
				.setSenke(OdPrognoseGanglinienAnfrage.Aspekte.Anfrage.getAspekt(), true);
		glProg.getOnlineDatensatz(OdPrognoseGanglinienAnfrage.class)
				.addUpdateListener(OdPrognoseGanglinienAnfrage.Aspekte.Anfrage.getAspekt(), this);
	}

	@Override
	public void datensatzAktualisiert(final DatensatzUpdateEvent event) {
		try {
			final OdPrognoseGanglinienAnfrage.Daten daten = (OdPrognoseGanglinienAnfrage.Daten) event.getDatum();

			if (daten.isValid()) {

				final Applikation app = daten.getAbsender();
				final OdPrognoseGanglinienAntwort antwort = app.getOnlineDatensatz(OdPrognoseGanglinienAntwort.class);
				antwort.anmeldenSender(OdPrognoseGanglinienAntwort.Aspekte.Antwort.getAspekt());

				final OdPrognoseGanglinienAntwort.Daten antwortDaten = antwort.erzeugeDatum();
				antwortDaten.setAbsenderZeichen(daten.getAbsenderZeichen());

				final Iterator<GlProgAnfrage> iterator = daten.iterator();
				while (iterator.hasNext()) {
					final GlProgAnfrage anfrage = iterator.next();
					final GanglinieMQ ganglinie = new GanglinieMQ();
					ganglinie.setApproximationDaK(GanglinieMQ.APPROX_POLYLINE);
					ganglinie.setMessQuerschnitt(anfrage.getMessQuerschnitt());
					ganglinie.setPrognoseZeitraum(anfrage.getPrognoseZeitraum());
					ganglinie.putAll(netz.getGanglinienDaten(anfrage.getMessQuerschnitt(),
							anfrage.getPrognoseZeitraum(), anfrage.isNurLangfristigeAuswahl()));
					antwortDaten.add(ganglinie);
				}

				antwort.sendeDaten(OdPrognoseGanglinienAntwort.Aspekte.Antwort.getAspekt(), antwortDaten);
			}

		} catch (final AnmeldeException e) {
			Assert.fail(e.getMessage());
		} catch (final DatensendeException e) {
			Assert.fail(e.getMessage());
		}
	}
}
