/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnitt;

/**
 * Repräsentation des MQ1 des Testnetzes (siehe Prüfspezifikation).
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class TestMQ1 extends TestMQ {

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Boolean[] ANFRAGETYPEN = { null, false, null, null, null, null, false, false, null, false,
			false, false };

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Double[][] GLDATEN = { {}, { 3921.0, 3981.5, 4011.75 }, { 4025.0, 4077.0, 4103.0 },
			{ 4100.0, 4137.5, 4156.25 }, { 4200.0, 4250.0, 4275.0 }, { 4300.0, 4350.0, 4375.0 },
			{ 4100.0, 4000.0, 3950.0 }, { 4400.0, 4550.0, 4625.0 }, { 4300.0, 4250.0, 4225.0 },
			{ 2000.0, 850.0, 275.0 }, { 2220.0, 2330.0, 2385.0 }, { 1300.0, 840.0, 610.0 }, { 1300.0, 1300.0, 1300.0 },
			{ 1200.0, 1150.0, 1125.0 }, { 1150.0, 1125.0, 1112.5 }, { 1200.0, 1225.0, 1237.5 } };

	/**
	 * Konstruktor.
	 *
	 * @param mq
	 *            der verwendete Messquerschnitt
	 * @param start
	 *            der Startzeitpunkt des Tests
	 * @param intervall
	 *            das Intervall für die Phasen des Tests
	 * @throws AnmeldeException
	 *             eine erforderliche Anmeldung beim Datenverteiler ist
	 *             fehlgeschlagen
	 */
	public TestMQ1(final MessQuerschnitt mq, final long start, final long intervall) throws AnmeldeException {
		super(mq, start, intervall);
	}

	@Override
	public Boolean[] getGlAnfrageTypen() {
		return TestMQ1.ANFRAGETYPEN;
	}

	@Override
	public Double[] getPhasenDaten(final int phasenNummer, final boolean nurLangFristig) {
		if (TestMQ1.GLDATEN.length > phasenNummer) {
			return TestMQ1.GLDATEN[phasenNummer];
		}
		return new Double[] {};
	}

}
