/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.DatensendeException;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnitt;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.parameter.PdFundamentalDiagramm;

/**
 * Repräsentation des MQ4 des Testnetzes (siehe Prüfspezifikation).
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class TestMQ4 extends TestMQ {

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Boolean[] ANFRAGETYPEN = {};

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Double[][] GLDATEN = { {}, { 2040.0, 1860.0, 1770.0 }, { 1750.0, 1605.0, 1532.5 },
			{ 1480.0, 1345.0, 1277.5 }, { 1380.0, 1330.0, 1305.0 }, { 1280.0, 1230.0, 1205.0 },
			{ 1300.0, 1310.0, 1315.0 }, { 1400.0, 1450.0, 1475.0 }, { 2880.0, 3620.0, 3990.0 },
			{ 3200.0, 3360.0, 3440.0 }, { null, 2630.0, 2535.0 }, { 2600.0, 2490.0, 2435.0 },
			{ 2500.0, 2450.0, 2425.0 }, { 2300.0, 2200.0, 2150.0 }, { 2200.0, 2150.0, 2125.0 } };

	/**
	 * Konstruktor.
	 *
	 * @param mq
	 *            der verwendete Messquerschnitt
	 * @param start
	 *            der Startzeitpunkt des Tests
	 * @param intervall
	 *            das Intervall für die Phasen des Tests
	 * @throws AnmeldeException
	 *             eine erforderliche Anmeldung beim Datenverteiler ist
	 *             fehlgeschlagen
	 * @throws DatensendeException
	 *             Parameterdaten für Fundamentaldiagramm konnten nicht
	 *             versendet werden
	 */
	public TestMQ4(final MessQuerschnitt mq, final long start, final long intervall)
			throws AnmeldeException, DatensendeException {
		super(mq, start, intervall);

		final PdFundamentalDiagramm datenSatz = mq.getParameterDatensatz(PdFundamentalDiagramm.class);
		datenSatz.anmeldenSender();
		final PdFundamentalDiagramm.Daten datum = datenSatz.erzeugeDatum();
		datum.setQ0(2400);
		datum.setK0((short) 0);
		datum.setV0((short) 0);
		datum.setVFrei((short) 0);
		datenSatz.sendeDaten(datum);
		datenSatz.abmeldenSender();
	}

	@Override
	protected Boolean[] getGlAnfrageTypen() {
		return TestMQ4.ANFRAGETYPEN;
	}

	@Override
	public Double[] getPhasenDaten(final int phasenNummer, final boolean nurLangFristig) {
		if (TestMQ4.GLDATEN.length > phasenNummer) {
			return TestMQ4.GLDATEN[phasenNummer];
		}
		return new Double[] {};
	}

}
