/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnitt;

/**
 * Repräsentation des MQ der Zufahrt der AS1 (siehe Prüfspezifikation).
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class TestMQAs1Zu extends TestMQ {

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Boolean[] ANFRAGETYPEN = { null, true, null, null, null, null, true, true, null, true, true,
			true };

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Double[][] GLDATEN = { {}, { 870.0, 815.0, 787.5 }, { 900.0, 915.0, 922.5 },
			{ 920.0, 930.0, 935.0 }, { 1002.0, 1043.0, 1063.5 }, { 37.0, -445.5, -686.75 }, { 42.0, 44.5, 45.75 },
			{ 51.0, 55.5, 57.75 }, { 48.0, 46.5, 45.75 }, { 41.0, 37.5, 35.75 }, { 41.0, 41.0, 41.0 },
			{ 43.0, 44.0, 44.5 }, { 44.0, 44.5, 44.75 }, { 51.0, 54.5, 56.25 }, { 45.0, 42.0, 40.5 },
			{ 39.0, 36.0, 34.5 } };

	/** die Ganglinie des MQ für langfristige Prognose. */
	private static final Double[] GLLANG = { 1120.0, 1240.0, 1200.0, 40.0, 38.0, 35.0, 30.0, 30.0, 28.0, 26.0, 24.0,
			23.0, 25.0, 26.0, 28.0, 32.0, 38.0, 44.0, 50.0, 58.0 };

	/**
	 * Konstruktor.
	 *
	 * @param mq
	 *            der verwendete Messquerschnitt
	 * @param start
	 *            der Startzeitpunkt des Tests
	 * @param intervall
	 *            das Intervall für die Phasen des Tests
	 * @throws AnmeldeException
	 *             eine erforderliche Anmeldung beim Datenverteiler ist
	 *             fehlgeschlagen
	 */
	public TestMQAs1Zu(final MessQuerschnitt mq, final long start, final long intervall) throws AnmeldeException {
		super(mq, start, intervall);
		// TODO Auto-generated constructor stub
	}

	@Override
	public Boolean[] getGlAnfrageTypen() {
		return TestMQAs1Zu.ANFRAGETYPEN;
	}

	@Override
	public Double[] getPhasenDaten(final int phasenNummer, final boolean nurLangFristig) {
		Double[] result = null;
		if (nurLangFristig) {
			if (TestMQAs1Zu.GLLANG.length > phasenNummer) {
				result = new Double[TestMQAs1Zu.GLLANG.length - phasenNummer];
				System.arraycopy(TestMQAs1Zu.GLLANG, phasenNummer, result, 0, TestMQAs1Zu.GLLANG.length - phasenNummer);
			}
		} else {
			if (TestMQAs1Zu.GLDATEN.length > phasenNummer) {
				result = TestMQAs1Zu.GLDATEN[phasenNummer];
			}
		}

		if (result == null) {
			result = new Double[] {};
		}
		return result;
	}
}
