/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.DatensendeException;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.StrassenTeilSegment;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.parameter.PdFundamentalDiagramm;

/**
 * Repräsentation eines Straßenteilsegments innerhalb des für die Prüfung
 * vorgesehenen Netzes.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */

public class TestSts extends TestIndikator {

	/**
	 * Konstruktor.
	 *
	 * @param sts
	 *            das verwendete Straßenteilsegment
	 * @throws AnmeldeException
	 *             es konnten nicht alle erforderlichen Anmeldungen beim
	 *             Datenverteiler ausgeführt werden.
	 * @throws DatensendeException
	 *             die erforderlichen Daten konnten nicht versendet werden
	 */
	public TestSts(final StrassenTeilSegment sts) throws AnmeldeException, DatensendeException {
		super(sts);

		final PdFundamentalDiagramm datenSatz = sts.getParameterDatensatz(PdFundamentalDiagramm.class);
		datenSatz.anmeldenSender();
		final PdFundamentalDiagramm.Daten datum = datenSatz.erzeugeDatum();

		if ("sts.ass4.sts2".equals(sts.getPid())) {
			datum.setQ0(2600);
		} else if ("sts.ass4.sts3".equals(sts.getPid())) {
			datum.setQ0(2400);
		} else {
			datum.setQ0(3600);
		}
		datum.setK0((short) 0);
		datum.setV0((short) 0);
		datum.setVFrei((short) 0);
		datenSatz.sendeDaten(datum);
		datenSatz.abmeldenSender();
	}
}
